@@ -1,7 +1,9 @@
 from .elv import (
     Parse,
+    ParseSSB,
     Transaction,
     Transactions,
+    formats,
     parse,
     parse_stream,
 )
@@ -9,13 +11,15 @@ from .elv import (
 __author__ = "Christian Stigen Larsen"
 __copyright__ = "Copyright (C) 2015 Christian Stigen Larsen"
 __email__ = "csl@csl.name"
-__license__ = "AGPL v3 or later"
-__version__ = "1.0.1"
+__license__ = "Affero GPL v3 or later"
+__version__ = "1.0.7"
 
 __all__ = [
     "Parse",
+    "ParseSSB",
     "Transaction",
     "Transactions",
+    "formats",
     "parse",
     "parse_stream",
 ]
